var class_pro_s_h_a_d_e__settings =
[
    [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#a5dc483c889427fdae60c740a106ce3ff", null ],
    [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#ae88f04ca81dc11f83329552e9f8e0d4c", null ],
    [ "~ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#a46ba91a2feeaccb274bc01aff5efb9c2", null ],
    [ "addStructure", "class_pro_s_h_a_d_e__settings.html#a0024967775d544e8512b6b157d53c1d1", null ],
    [ "determineAllSHValues", "class_pro_s_h_a_d_e__settings.html#a450e03005d24cc3e58d2d05fb3bc5027", null ],
    [ "determineBandwidth", "class_pro_s_h_a_d_e__settings.html#a46a4b300f5f4c507edcd208e1fcb9df7", null ],
    [ "determineBandwidthFromAngle", "class_pro_s_h_a_d_e__settings.html#a25080bd03aaf7a4ce834f0df7aaa4250", null ],
    [ "determineIntegrationOrder", "class_pro_s_h_a_d_e__settings.html#a6d2b5d90f31a1493e17474a044852da6", null ],
    [ "determineSphereDistances", "class_pro_s_h_a_d_e__settings.html#a4436b5eeb922db0351874eb64f350920", null ],
    [ "getCommandLineParams", "class_pro_s_h_a_d_e__settings.html#a52c1b3d4e86737c42785c0740b1f5497", null ],
    [ "printSettings", "class_pro_s_h_a_d_e__settings.html#a39cd81c30db3d72f279edb9b0c29a080", null ],
    [ "setAppliedMaskFilename", "class_pro_s_h_a_d_e__settings.html#afd3ffe30dc16424e5cc72a6cf750daec", null ],
    [ "setAxisComparisonThreshold", "class_pro_s_h_a_d_e__settings.html#a41cdb46d64d149ee521b9a4e6ccee6de", null ],
    [ "setAxisComparisonThresholdBehaviour", "class_pro_s_h_a_d_e__settings.html#a74d3a2527a40c584af6bdb32896e8af0", null ],
    [ "setBandwidth", "class_pro_s_h_a_d_e__settings.html#a09da7265a83b7f5b6bef614f95a471d6", null ],
    [ "setBicubicInterpolationSearch", "class_pro_s_h_a_d_e__settings.html#a4cc1e3d2625cfaeda834c583b47e39c5", null ],
    [ "setBoundsSpace", "class_pro_s_h_a_d_e__settings.html#a173a6e8c54ff7d6ed0558d3d34523de3", null ],
    [ "setBoundsThreshold", "class_pro_s_h_a_d_e__settings.html#add15920c73e6255d517e2d97794bcdd5", null ],
    [ "setCorrelationMasking", "class_pro_s_h_a_d_e__settings.html#a412cbcb39b4ce0e18e080aa35cb1cbce", null ],
    [ "setDetectedSymmetry", "class_pro_s_h_a_d_e__settings.html#aaacee048ce8a3489edc77afcb54f0ca0", null ],
    [ "setEnergyLevelsComputation", "class_pro_s_h_a_d_e__settings.html#ad2d51c260ed88aaaa50dd7ca75bfc648", null ],
    [ "setEnLevShellWeight", "class_pro_s_h_a_d_e__settings.html#a07bb5091a2a7f008b6a5a3a74ad32681", null ],
    [ "setExtraSpace", "class_pro_s_h_a_d_e__settings.html#a4f6ef17085b2eb8181c66bd85648e513", null ],
    [ "setFSCThreshold", "class_pro_s_h_a_d_e__settings.html#affdc86810291f09a7d70065fced76e91", null ],
    [ "setGroupingSmoothingFactor", "class_pro_s_h_a_d_e__settings.html#a8b666e89ab4352df317eb5c7c0cb446e", null ],
    [ "setIntegrationOrder", "class_pro_s_h_a_d_e__settings.html#a7889a7b3794f25cef3777436b1f199e3", null ],
    [ "setMapCentering", "class_pro_s_h_a_d_e__settings.html#a7b348b316612d2b20ae8c36ff2bce584", null ],
    [ "setMapInversion", "class_pro_s_h_a_d_e__settings.html#aa70d5ace2805cced4c22976fdaf29c23", null ],
    [ "setMapReboxing", "class_pro_s_h_a_d_e__settings.html#ab6b43957e2ff946c9c072f82432e1c4b", null ],
    [ "setMapResolutionChange", "class_pro_s_h_a_d_e__settings.html#ae7aad96d952d4ca192d11be5b72d47c6", null ],
    [ "setMapResolutionChangeTriLinear", "class_pro_s_h_a_d_e__settings.html#aa96a2a48c31635c52dbcebfa84851170", null ],
    [ "setMaskBlurFactor", "class_pro_s_h_a_d_e__settings.html#a659b07410168e301b61a64f79fc8f990", null ],
    [ "setMaskFilename", "class_pro_s_h_a_d_e__settings.html#a6f94c707497f855749fc7204a6727a62", null ],
    [ "setMasking", "class_pro_s_h_a_d_e__settings.html#aae9f1582c7bceaa5898df7c5b38dd1c7", null ],
    [ "setMaskIQR", "class_pro_s_h_a_d_e__settings.html#a8036c97bd98f53074deae6aee7e81fce", null ],
    [ "setMaskSaving", "class_pro_s_h_a_d_e__settings.html#a721ec7323e62706bf3b1b81c47036e8e", null ],
    [ "setMaxSymmetryFold", "class_pro_s_h_a_d_e__settings.html#aa6e624f5aac091c3be14d3cce4efeb1c", null ],
    [ "setMinimumMaskSize", "class_pro_s_h_a_d_e__settings.html#ad9684f6daecbcd47d3a0651cf46f6956", null ],
    [ "setMinimumPeakForAxis", "class_pro_s_h_a_d_e__settings.html#a2d8f84b127717648cf9aa1aa92ce7c0f", null ],
    [ "setMissingPeakThreshold", "class_pro_s_h_a_d_e__settings.html#a1a228d80e0516eed6ee8bbd81bd91a8a", null ],
    [ "setNegativeDensity", "class_pro_s_h_a_d_e__settings.html#abd1069a4a110e954a516406eb70a8933", null ],
    [ "setNormalisation", "class_pro_s_h_a_d_e__settings.html#af5b8d95fdf6f00aee751bd688187f8cf", null ],
    [ "setOutputFilename", "class_pro_s_h_a_d_e__settings.html#a02204845243741c4d73353c0319fc9e2", null ],
    [ "setOverlayJsonFile", "class_pro_s_h_a_d_e__settings.html#a5d3d521f7d3c7e20d5980fe3deeedd3f", null ],
    [ "setOverlaySaveFile", "class_pro_s_h_a_d_e__settings.html#adbe7012b771262d46b4a6c175c66f6ab", null ],
    [ "setPDBBFactor", "class_pro_s_h_a_d_e__settings.html#ab5e32721e570d63fba20e15be41428e0", null ],
    [ "setPeakNaiveNoIQR", "class_pro_s_h_a_d_e__settings.html#ab929802319773a9ae49a6e5cf9ae0c66", null ],
    [ "setPeakNeighboursNumber", "class_pro_s_h_a_d_e__settings.html#aa412b57c600caa1915c99bee1135d157", null ],
    [ "setPeakThreshold", "class_pro_s_h_a_d_e__settings.html#a754c633261eb363bfb496a234ace79e6", null ],
    [ "setPhaseUsage", "class_pro_s_h_a_d_e__settings.html#a7666952b5e417490ba20b52a8e9a8c9d", null ],
    [ "setProgressiveSphereMapping", "class_pro_s_h_a_d_e__settings.html#aa8865b59b86447f584b92841113fde1e", null ],
    [ "setRecommendedFold", "class_pro_s_h_a_d_e__settings.html#a96a407a325278aec10d10a15c480c077", null ],
    [ "setRecommendedSymmetry", "class_pro_s_h_a_d_e__settings.html#a974bbe07f5435f052df4592825ed7aba", null ],
    [ "setRequestedFold", "class_pro_s_h_a_d_e__settings.html#a6c413035f4c9c5a782ccca2b02037e53", null ],
    [ "setRequestedSymmetry", "class_pro_s_h_a_d_e__settings.html#a7e79193dd146f977d511d755b9189411", null ],
    [ "setResolution", "class_pro_s_h_a_d_e__settings.html#a3e7f4174b62aa402a1f6d3becd8e9dd5", null ],
    [ "setRotationFunctionComputation", "class_pro_s_h_a_d_e__settings.html#adc025bad387952e9a2b9395775ad7903", null ],
    [ "setSameBoundaries", "class_pro_s_h_a_d_e__settings.html#aa84f6622f8b7ac034f171cbe29d3bcab", null ],
    [ "setSphereDistances", "class_pro_s_h_a_d_e__settings.html#a5e84faf0910dadc44f0add82443e839e", null ],
    [ "setSymmetryRotFunPeaks", "class_pro_s_h_a_d_e__settings.html#a904d9eb8c4ed8183f83ff6ae82da1921", null ],
    [ "setTaylorSeriesCap", "class_pro_s_h_a_d_e__settings.html#acf005edf3e38fe6050d25f8910d3f079", null ],
    [ "setTraceSigmaComputation", "class_pro_s_h_a_d_e__settings.html#a2e5acd2c944f50fe4736be5c738e61fd", null ],
    [ "setTypicalNoiseSize", "class_pro_s_h_a_d_e__settings.html#ac5b55f7ece119e9d9e980d89d59a6df8", null ],
    [ "setVariablesLeftOnAuto", "class_pro_s_h_a_d_e__settings.html#a192954646aa4b895b5fc522e79ea38cf", null ],
    [ "setVerbosity", "class_pro_s_h_a_d_e__settings.html#ac61aa28892ae42710b7a90f4fdf9c05a", null ],
    [ "addExtraSpace", "class_pro_s_h_a_d_e__settings.html#afb42ec0cd0f8abb54327c0e2c3025ed1", null ],
    [ "allDetectedCAxes", "class_pro_s_h_a_d_e__settings.html#a2ac59de43dacdd96c7f89811f80d2e7e", null ],
    [ "allDetectedDAxes", "class_pro_s_h_a_d_e__settings.html#a618c04a2c1d7f0a506d0bb3d7a0da444", null ],
    [ "allDetectedIAxes", "class_pro_s_h_a_d_e__settings.html#aa4957b0a47193ef1042028dc22b350f6", null ],
    [ "allDetectedOAxes", "class_pro_s_h_a_d_e__settings.html#a4d869a528d0af64bc3688a9a48514061", null ],
    [ "allDetectedTAxes", "class_pro_s_h_a_d_e__settings.html#ae42ba1e294d1887c71b763f9bb5519cc", null ],
    [ "appliedMaskFileName", "class_pro_s_h_a_d_e__settings.html#a670cffe28bbdac027bffd8f5491d4266", null ],
    [ "axisErrTolerance", "class_pro_s_h_a_d_e__settings.html#a4627b03c4064d3de15efb3ebbf57ed78", null ],
    [ "axisErrToleranceDefault", "class_pro_s_h_a_d_e__settings.html#a3894488e487198646796506ed44e468d", null ],
    [ "blurFactor", "class_pro_s_h_a_d_e__settings.html#a51c87d0b415c8eaa517dbb9b5496e7e9", null ],
    [ "boundsExtraSpace", "class_pro_s_h_a_d_e__settings.html#a633435d4c8a7fd6533016c00ad9ba791", null ],
    [ "boundsSimilarityThreshold", "class_pro_s_h_a_d_e__settings.html#a827e3241fa6401027e0526fffb8b281d", null ],
    [ "changeMapResolution", "class_pro_s_h_a_d_e__settings.html#ab61d2183930ea26b3d49e7662052e83b", null ],
    [ "changeMapResolutionTriLinear", "class_pro_s_h_a_d_e__settings.html#a4f49a4f2263aa12ccb1737f8dc32c9ac", null ],
    [ "computeEnergyLevelsDesc", "class_pro_s_h_a_d_e__settings.html#a23a96d41d415195813dd3237ae47b614", null ],
    [ "computeRotationFuncDesc", "class_pro_s_h_a_d_e__settings.html#a4ee1d1392407d1317274a793186129aa", null ],
    [ "computeTraceSigmaDesc", "class_pro_s_h_a_d_e__settings.html#a48bff4bebb6268c286b68bfd6663d954", null ],
    [ "correlationKernel", "class_pro_s_h_a_d_e__settings.html#ad7070cc8a98a8b8a040232eae8b2fbf3", null ],
    [ "detectedSymmetry", "class_pro_s_h_a_d_e__settings.html#a42b012ec753ebd1d87a0b6f557e97d1a", null ],
    [ "enLevMatrixPowerWeight", "class_pro_s_h_a_d_e__settings.html#a85edabe260e0466726b5875969dd18e3", null ],
    [ "firstModelOnly", "class_pro_s_h_a_d_e__settings.html#a0ee28b12499554d8dff8752cd5ef072a", null ],
    [ "forceBounds", "class_pro_s_h_a_d_e__settings.html#aa3e24ef5a66fa7204a2ba9c27f2f12b9", null ],
    [ "forceP1", "class_pro_s_h_a_d_e__settings.html#acffa14a2c2121b5b425fcabdb7b3ba6a", null ],
    [ "fscThreshold", "class_pro_s_h_a_d_e__settings.html#a53120c9e4f3f1f69f80d7c966dff2cb7", null ],
    [ "halfMapKernel", "class_pro_s_h_a_d_e__settings.html#a8d2299cb1a7b0470e0f26e431af2548f", null ],
    [ "inputFiles", "class_pro_s_h_a_d_e__settings.html#a8a032c43a41e79e9d86c5beccb329169", null ],
    [ "integOrder", "class_pro_s_h_a_d_e__settings.html#af696bcba16302fe3a42e0341b4c5415a", null ],
    [ "invertMap", "class_pro_s_h_a_d_e__settings.html#a0d205c102e722997ab1f0953f76a288a", null ],
    [ "maskFileName", "class_pro_s_h_a_d_e__settings.html#affb17d9099f0b85b3af04a78d5c670f4", null ],
    [ "maskingThresholdIQRs", "class_pro_s_h_a_d_e__settings.html#a7c96697585083a53f83556e70e4faca8", null ],
    [ "maskMap", "class_pro_s_h_a_d_e__settings.html#a7c941c912cd17ad86057b8d7a15b9a21", null ],
    [ "maxBandwidth", "class_pro_s_h_a_d_e__settings.html#a8324ed7ec9c19df21511f117df80ab11", null ],
    [ "maxSphereDists", "class_pro_s_h_a_d_e__settings.html#a42e4b11981a2d3a518cb3c70e5470fb2", null ],
    [ "maxSymmetryFold", "class_pro_s_h_a_d_e__settings.html#afcece610f52c27cadefb217f1d0c278c", null ],
    [ "minSymPeak", "class_pro_s_h_a_d_e__settings.html#ac914dc8b6ee2e35286beabb1b6611b74", null ],
    [ "moveToCOM", "class_pro_s_h_a_d_e__settings.html#a37c9037721c1ad28ad6421a31dbcd8d8", null ],
    [ "noIQRsFromMedianNaivePeak", "class_pro_s_h_a_d_e__settings.html#a3e7948fd9177bd39ed3dd2320ea2b0bc", null ],
    [ "normaliseMap", "class_pro_s_h_a_d_e__settings.html#a0d796061e73e8635f75fc6921b98ad66", null ],
    [ "outName", "class_pro_s_h_a_d_e__settings.html#a520b751f6c9f72ce8f0a557b4de04376", null ],
    [ "overlayStructureName", "class_pro_s_h_a_d_e__settings.html#a833f51d5da64ed09004daa4bf66c013c", null ],
    [ "pdbBFactorNewVal", "class_pro_s_h_a_d_e__settings.html#a3cac1bd635aabf3a3370fc26dfa0f49a", null ],
    [ "peakNeighbours", "class_pro_s_h_a_d_e__settings.html#a26b57d39529ca69a117aceead6b12680", null ],
    [ "peakThresholdMin", "class_pro_s_h_a_d_e__settings.html#a4af89abc1c94e4a6df28c7b31f576551", null ],
    [ "progressiveSphereMapping", "class_pro_s_h_a_d_e__settings.html#a2f1e4debc49664de8842d1b42be74d2d", null ],
    [ "reBoxMap", "class_pro_s_h_a_d_e__settings.html#a90f225894304c4894f6106498e1d7729", null ],
    [ "recommendedSymmetryFold", "class_pro_s_h_a_d_e__settings.html#ac8e62cc8dbd40265e51143c8207b6638", null ],
    [ "recommendedSymmetryType", "class_pro_s_h_a_d_e__settings.html#ac39560ba9aca9053753c158fb2adb9de", null ],
    [ "removeNegativeDensity", "class_pro_s_h_a_d_e__settings.html#ad42474a333f9b605ccad7ecfb72afb2e", null ],
    [ "removeWaters", "class_pro_s_h_a_d_e__settings.html#acea4abeec3e2b45524e23809a69dce9d", null ],
    [ "requestedResolution", "class_pro_s_h_a_d_e__settings.html#a7d0a63b2ac89e4f0df85ce5053c6bd87", null ],
    [ "requestedSymmetryFold", "class_pro_s_h_a_d_e__settings.html#a6dc170d9826bad9ce4a2c31a033f7f6a", null ],
    [ "requestedSymmetryType", "class_pro_s_h_a_d_e__settings.html#ab59297b3604ced939e30eaacd2eaaccb", null ],
    [ "rotationUncertainty", "class_pro_s_h_a_d_e__settings.html#ad9c57832756d4ea342589104cdaded6b", null ],
    [ "rotTrsJSONFile", "class_pro_s_h_a_d_e__settings.html#a30a0c63c3ab63d603776c9a16e1e4044", null ],
    [ "saveMask", "class_pro_s_h_a_d_e__settings.html#a29445fb6221eed35a32147814a3f58d5", null ],
    [ "smoothingFactor", "class_pro_s_h_a_d_e__settings.html#a84e490954883961abf92b9ed5b3cae65", null ],
    [ "symMissPeakThres", "class_pro_s_h_a_d_e__settings.html#a43e4918d4e7d08787d47788a6dae16ba", null ],
    [ "task", "class_pro_s_h_a_d_e__settings.html#afb39c3bb75f1b925175f9f6b09ada148", null ],
    [ "taylorSeriesCap", "class_pro_s_h_a_d_e__settings.html#abebc53842ab9dd92685f66c950a2fc44", null ],
    [ "useBiCubicInterpolationOnPeaks", "class_pro_s_h_a_d_e__settings.html#afb183823a47a73d459a5bae16042bf4e", null ],
    [ "useCorrelationMasking", "class_pro_s_h_a_d_e__settings.html#a9f2447c98c5d2f2aa0768f7599f8954f", null ],
    [ "usePeakSearchInRotationFunctionSpace", "class_pro_s_h_a_d_e__settings.html#ab8d152f5e2e5dc0a64048d2e9c0d8d12", null ],
    [ "usePhase", "class_pro_s_h_a_d_e__settings.html#a2019a6bae1b3e6f7d8805ae2734b769e", null ],
    [ "useSameBounds", "class_pro_s_h_a_d_e__settings.html#a1f0d2cb45fee521ddb2d0bc30beff3ec", null ],
    [ "verbose", "class_pro_s_h_a_d_e__settings.html#a89094c73ae033812d4df0bd846e03442", null ]
];